//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	odfexpand.cc --- expand an symbolic ODF file name specification
//
//	DESCRIPTION:
//		This tool expands an ODF file name specification in either of
//		the forms specified in the description of OAL function
//		OAL_selectFile(). The program expects a single string on the
//		command line and writes to <stdout> the full name (dir + basename)
//		of a matching ODF file. The environment variable 'SAS_ODFDIR' must
//		point to a directory containing an ODF summary file or the
//		directory name must be given via the generic -o or --odirdir task
//		command line option.
//
//		If the specified file does not exist, a corresponding error
//		message is issued and the program exits with non-zero return value.
//
//	CHANGE HISTORY:
//		UL, 1998-08-19: 1.0.0: - initial version
//		UL, 1999-02-04: 1.1.0: - in line-with OAL v2.11
//							   - made it a proper task; GV's other odfexpand
//								 task is now obsolete
//
//	AUTHOR:
//		U. Lammers, Wed Aug 19 14:07:53 MET DST 1998
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /usr/local/cvs/sasdev/task_devel/packages/tools/src/odfexpand/odfexpand.cc,v 1.3 2001/04/02 12:37:30 ulammers Exp $
//
#include <iostream>
#include <cassert>
#include "param.h"
#include "OalServer.h"

#include "odfexpand.h"

void odfexpand()
{
	const OdfSet *odfSet =
		oalServer.odf()->selectSet(stringParameter("odfrequest"));

	assert(odfSet);
	cout<<odfSet->name()<<endl;
}
